4.34. umbra.managers.notificationsManager — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.34. umbra.managers.notificationsManager

notificationsManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `NotificationsManager` and `Notification` classes.

Others:

## 4.34.1. Module Attributes

`umbra.managers.notificationsManager.` `LOGGER`

## 4.34.2. Classes

class `umbra.managers.notificationsManager.` `Notification`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for `NotificationsManager` class notification.

  Parameters: | **kwargs – message, time. ( Key / Value pairs )

class `umbra.managers.notificationsManager.` `NotificationsManager`(parent=None)

  Bases: `PyQt4.QtCore.QObject`

  This class defines the Application notifications manager.

  `notificationRegistered`

    This signal is emited by the `NotificationsManager` class when a notification is registered. ( pyqtSignal )

    Returns: | Current registered notification. ( Notification )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `notifications`

    This method is the property for self.__notifications attribute.

    Returns: | self.__notifications. ( List )

  `notifiers`

    This method is the property for self.__notifiers attribute.

    Returns: | self.__notifiers. ( List )

  `notifiersStackPadding`

    This method is the property for self.__notifiersStackPadding attribute.

    Returns: | self.__notifiersStackPadding. ( Integer )

  `listNotifications`()

    This method returns the registered notifications.

    Returns: | Notifications list. ( List )

  `isNotificationRegistered`(notification)

    This method returns if the given notification is registered.

    Parameters: | notification – Notification. ( String )
    Returns: | Is notification registered. ( Boolean )

  `registerNotification`(notification)

    This method registers given notification.

    Parameters: | notification – Notification to register. ( Notification )
    Returns: | Method success. ( Boolean )

  `formatNotification`(notification)

    This method formats given notification.

    Parameters: | notification – Notification to format. ( Notification )
    Returns: | Method success. ( Boolean )

  `notify`(message, duration=3000, notificationClickedSlot=None, messageLevel=u'Information', **kwargs)

    This method displays an Application notification.

    Parameters: | message – Notification message. ( String ) duration – Notification display duration. ( Integer ) notificationClickedSlot – Notification clicked slot. ( Object ) messageLevel – Message level ( “Information”, “Warning”, “Exception” ). ( String ) **kwargs – Keywords arguments. ( ** )
    Returns: | Method success. ( Boolean )

  `warnify`(message, duration=3000, notificationClickedSlot=None, **kwargs)

    This method displays an Application notification warning.

    Parameters: | message – Notification message. ( String ) duration – Notification display duration. ( Integer ) notificationClickedSlot – Notification clicked slot. ( Object ) **kwargs – Keywords arguments. ( ** )
    Returns: | Method success. ( Boolean )

  `exceptify`(message, duration=3000, notificationClickedSlot=None, **kwargs)

    This method displays an Application notification exception.

    Parameters: | message – Notification message. ( String ) duration – Notification display duration. ( Integer ) notificationClickedSlot – Notification clicked slot. ( Object ) **kwargs – Keywords arguments. ( ** )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »